/*
Kholoud Khateeb, Craig Ward
CMSI 698, Internet Technologies
Homework Assignment 1, February 6, 2003
*/
import java.net.Socket;
import java.net.ServerSocket;
import java.util.Date;
import java.io.PrintWriter;
import java.io.IOException;
// Additions
import java.io.InputStreamReader;
import java.io.BufferedReader;
import java.text.SimpleDateFormat;

/**
 * A TCP server that runs on port 9090.  When a client connects, the server
 * reads the request and then responds with one of three text formats for the
 * date:
 *
 * keyword         action
 * -------         ------
 * iso             Return an ISO 8601 formatted string
 * default         Return the default Java format
 * epochrelative   Return number of seconds since the "epoch"
 *
 * The "epoch" begins January 1, 1970.
 */
public class DateServer {    

    /**
     * Runs the server.
     */
    public static void main(String[] args) throws IOException {
	log("DateServer startup");
        ServerSocket listener = new ServerSocket(9090);
        try {
            while (true) {
                Socket socket = listener.accept();
                try {
		    log("\tAccepted connection");
		    BufferedReader in = new 
			BufferedReader(new InputStreamReader(socket.getInputStream()));
		    String request = in.readLine();
		    log("\tRequest: " + request);
                    PrintWriter out = 
			new PrintWriter(socket.getOutputStream(), true);
		    String response = doRequest(request);
		    if (response == null) response = "default";
		    log("\tResponse: " + response);
		    out.println(response);
		} catch (Exception e) {
		    log("error: " + e);
                } finally {
                    socket.close();
                }
            }
        }
        finally {
            listener.close();
	    log("DateServer terminated");
        }
    }

    private static String doRequest(String request)
    {
	String response = null;

	if (request.equalsIgnoreCase("iso")) {
	    SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss");
	    response = sdf.format(new Date());
	} else if (request.equalsIgnoreCase("epochrelative")) {
	    response = String.valueOf(new Date().getTime());
	} else {
	    response = new String(new Date().toString());
	}
	return response;
    }

    private static void log(String m)
    {
	System.out.println(m);
    }
}
